import time
import os
import board
import busio
import socketpool
import wifi
import adafruit_ntp
import adafruit_ssd1306
import adafruit_bmp180
import adafruit_framebuf

# I2C setup
i2c = busio.I2C(board.SCL, board.SDA)

# BMP180 sensor setup
bmp180 = adafruit_bmp180.Adafruit_BMP180_I2C(i2c)

# SSD1306 OLED display setup
oled_reset = None
WIDTH = 128
HEIGHT = 64
BORDER = 5

oled = adafruit_ssd1306.SSD1306_I2C(WIDTH, HEIGHT, i2c, addr=0x3C, reset=oled_reset)

# Clear the display
oled.fill(0)
oled.show()

# Get wifi AP credentials from a settings.toml file
wifi_ssid = os.getenv("CIRCUITPY_WIFI_SSID")
wifi_password = os.getenv("CIRCUITPY_WIFI_PASSWORD")
if wifi_ssid is None:
    print("WiFi credentials are kept in settings.toml, please add them there!")
    raise ValueError("SSID not found in environment variables")

try:
    wifi.radio.connect(wifi_ssid, wifi_password)
except ConnectionError:
    print("Failed to connect to WiFi with provided credentials")
    raise

pool = socketpool.SocketPool(wifi.radio)
ntp = adafruit_ntp.NTP(pool, tz_offset=1, cache_seconds=3600)

# Measurement location altitude (in meters)
altitude = 135

while True:
    # Read temperature and pressure from BMP180
    temperature = bmp180.temperature
    pressure = bmp180.pressure

    # Correct pressure to sea level
    sea_level_pressure = pressure * (1 - (altitude / 44330)) ** -5.255

    # Get current time and date from NTP
    current_time = ntp.datetime

    # Format time and date
    time_str = "{:02}:{:02}:{:02}".format(current_time.tm_hour, current_time.tm_min, current_time.tm_sec)
    date_str = "{:04}-{:02}-{:02}".format(current_time.tm_year, current_time.tm_mon, current_time.tm_mday)

    # Clear the display
    oled.fill(0)

    # Display the text
    oled.text(f"Temp: {temperature:.2f} C", 0, 0, 1)
    oled.text(f"Pressure: {sea_level_pressure:.2f} hPa", 0, 10, 1)
    oled.text(f"Time: {time_str}", 0, 20, 1)
    oled.text(f"Date: {date_str}", 0, 30, 1)

    # Update the display
    oled.show()

    # Wait before the next update
    time.sleep(2)
