import time
import board
import busio
import adafruit_ssd1306
import adafruit_bmp180
import adafruit_framebuf

# I2C setup
i2c = busio.I2C(board.SCL, board.SDA)

# BMP180 sensor setup
bmp180 = adafruit_bmp180.Adafruit_BMP180_I2C(i2c)

# SSD1306 OLED display setup
oled_reset = None
WIDTH = 128
HEIGHT = 64
BORDER = 5

oled = adafruit_ssd1306.SSD1306_I2C(WIDTH, HEIGHT, i2c, addr=0x3C, reset=oled_reset)

# Clear the display
oled.fill(0)
oled.show()

# Measurement location altitude (in meters)
altitude = 135

while True:
    # Read temperature and pressure from BMP180
    temperature = bmp180.temperature
    pressure = bmp180.pressure

    # Correct pressure to sea level
    sea_level_pressure = pressure * (1 - (altitude / 44330)) ** -5.255

    # Clear the display
    oled.fill(0)

    # Display the text
    oled.text(f"Temp: {temperature:.2f} C", 0, 0, 1)
    oled.text(f"Pressure: {sea_level_pressure:.2f} hPa", 0, 10, 1)

    # Update the display
    oled.show()

    # Wait before the next update
    time.sleep(2)
